@@ -32,7 +32,7 @@ def singleton(class_):
 
 
 class Worker:
-    def __init__(self, queue_name, metadata_table_name, should_wake_up=True, worker_name=None):
+    def __init__(self, queue_name, metadata_table_name, worker_name, should_wake_up=False):
         connection_string = os.environ['AzureWebJobsStorage']
         self.metadata_table_name = metadata_table_name
         self.table_client = TableService(connection_string=connection_string)
@@ -43,7 +43,6 @@ class Worker:
         if 'LtbCloudComponentsStorage' in os.environ:
             self.ltb_connection_string = os.environ['LtbCloudComponentsStorage']
 
-
     def trigger_blob(self, blob_name, data=None):
         request_id = self._insert_blob_metadata(blob_name, data)
         self._enqueue(request_id)
@@ -99,7 +98,7 @@ class Worker:
             if 'LtbCloudComponentsStorage' in os.environ:
                 track = traceback.format_exc()
                 function_failure_entity = {"PartitionKey": self.worker_name, "RowKey": request_id, "FailureMessage": str(e), "StackTrace": track}
-                TableService(connection_string=os.environ['LtbCloudComponentsStorage']).insert_entity(failure_table, function_failure_entity)
+                TableService(connection_string=self.ltb_connection_string).insert_entity(failure_table, function_failure_entity)
             else:
                 raise
 
